@@ -164,7 +164,7 @@ return sort { $a->{'name'} cmp $b->{'name'} }
 	 map { @{$_->{'users'}} } @{$_[0]};
 }
 
-# create_on_input(desc)
+# create_on_input(desc, [no-donthave])
 sub create_on_input
 {
 local @hosts = &list_webmin_hosts();
@@ -175,14 +175,16 @@ if ($_[0]) {
 	}
 print "<select name=server>\n";
 print "<option value=-1>$text{'user_all'}\n";
-print "<option value=-2>$text{'user_donthave'}\n";
+print "<option value=-2>$text{'user_donthave'}\n" if (!$_[1]);
 local @groups = &servers::list_all_groups(\@servers);
 local $h;
 foreach $h (@hosts) {
         local ($s) = grep { $_->{'id'} == $h->{'id'} } @servers;
-        print "<option value='$s->{'id'}'>",
-                $s->{'desc'} ? $s->{'desc'} : $s->{'host'};
-        $gothost{$s->{'host'}}++;
+	if ($s) {
+		print "<option value='$s->{'id'}'>",
+			$s->{'desc'} ? $s->{'desc'} : $s->{'host'},"\n";
+		$gothost{$s->{'host'}}++;
+		}
         }
 local $g;
 foreach $g (@groups) {
